CenterFloatingNavBar class

Inheritance

Constructors

CenterFloatingNavBar({Key? key, required List<NavBarItem> items, required int selectedIndex, required ValueChanged<int> onTap, VoidCallback? onFabTap, Color backgroundColor = Colors.white, Color selectedItemColor = Colors.deepOrangeAccent, Color unselectedItemColor = Colors.grey, double iconSize = 26, Color fabIconColor = Colors.white, IconData fabIcon = Icons.add, double fabSize = 60, Gradient fabGradient = const LinearGradient(colors: [Color(0xFFFF416C), Color(0xFFFF4B2B)], begin: Alignment.topLeft, end: Alignment.bottomRight), double fabElevation = 10.0, double fabBottomOffset = 25.0, NotchedShape bottomBarShape = const CustomCircularNotchedRectangle(), double notchMargin = 8.0})
const

Properties

backgroundColor Color
final
bottomBarShape NotchedShape
final
fabBottomOffset double
final
fabElevation double
final
fabGradient Gradient
final
fabIcon IconData
final
fabIconColor Color
final
fabSize double
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double
final
items List<NavBarItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notchMargin double
final
onFabTap VoidCallback?
final
onTap ValueChanged<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int
final
selectedItemColor Color
final
unselectedItemColor Color
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited